<template>
    <el-dialog
        v-if="dialogVisible"
        custom-class="easy-dialog"
        :visible.sync="dialogVisible"
        :show-close="false"
        top="6%"
        :append-to-body="true"
        :destroy-on-close="true"
    >
        <!-- 关闭图标 -->
        <img
            class="cloes-icon"
            src="@/assets/img/easy-dialog/icon_tck_close@3x.png"
            @click="handleClose"
        />
        <div class="title-diy">
            <div class="title">
                {{ title }}
            </div>
        </div>
        <!-- 内容默认插槽 #01215a-->
        <div
            class="content-diy"
            v-loading="loading"
            element-loading-background="rgba(1, 33, 90, 1)"
        >
            <div id="trend-chart"></div>
        </div>
    </el-dialog>
</template>

<script>
import * as echarts from 'echarts'
import apiList from '@/api/bigScreen/majorView.js'
export default {
    name: 'projectLinechartDialog',
    data() {
        return {
            title: '',
            dialogVisible: false,
            trendChart: null,
            trendChartOption: null,
            legendData: [],
            xAxisData: [],
            seriesData: [],
            valueData: [],
            rateData: null,
            loading: false,
        }
    },
    beforeDestroy() {
        this.$bus.$off('changeDate')
    },
    mounted() {
        // this.$bus.$on('changeDate', () => {
        //     this.loadData()
        // })
    },
    methods: {
        initTrendChart() {
            let chartDom = document.getElementById('trend-chart')
            this.trendChart = echarts.init(chartDom)
            this.trendChartOption = {
                title: {
                    text: this.title + '年度核心指标完成情况趋势图',
                    left: 'center',
                    bottom: '1%',
                    textStyle: {
                        color: '#ffffff',
                        fontSize: 18,
                        fontFamily: 'Microsoft YaHei, Microsoft YaHei',
                    },
                },
                tooltip: {
                    trigger: 'item', //'axis  item',
                    backgroundColor: 'rgba(6, 47, 107, 1)',
                    borderColor: 'rgba(2, 115, 233, 1)',
                    textStyle: {
                        color: '#fff',
                        fontSize: 18,
                    },
                    formatter: (arg) => {
                        console.log(arg, 'arg')
                        // let str = '截止' + arg[0].axisValue + '</br>'
                        // arg.forEach((item) => {
                        //     let index = item.dataIndex
                        //     let value = 0
                        //     if (
                        //         this.valueData[item.seriesName][index]
                        //             .actualIndexCompleteRate
                        //     ) {
                        //         value =
                        //             this.valueData[item.seriesName][index]
                        //                 .actualIndexCompleteRate
                        //     }

                        //     str =
                        //         str +
                        //         '<span style="display:inline-flex;font-size:16px;margin-top:5px;justify-content:center;align-items:center">' +
                        //         `<span style="display:inline-block;line-height:6px;width:20px;height:6px;background:${item.color};margin-right:4px;"></span>` +
                        //         item.seriesName +
                        //         '&nbsp;&nbsp;&nbsp;' +
                        //         value +
                        //         '%</span></br>'
                        // })

                        let str = '截止' + arg.name + '</br>'
                        str =
                            str +
                            '<span style="display:inline-flex;font-size:16px;margin-top:5px;justify-content:center;align-items:center">' +
                            `<span style="display:inline-block;line-height:6px;width:20px;height:6px;background:${arg.color};margin-right:4px;"></span>` +
                            arg.seriesName +
                            '&nbsp;&nbsp;&nbsp;' +
                            arg.data.actualRate +
                            '%</span>'

                        return str
                    },
                },
                legend: {
                    // top: '0',
                    // left: 'center',
                    type: 'plain',
                    icon: 'rect',
                    inactiveColor: '#333333',
                    itemWidth: 20,
                    itemHeight: 6,
                    textStyle: {
                        color: '#B1E3FF',
                        fontSize: 15,
                    },
                    data: this.legendData,
                },
                grid: {
                    left: '2%',
                    right: '120',
                    bottom: '10%',
                    top: '15%',
                    containLabel: true,
                },

                xAxis: {
                    type: 'category',
                    type: 'category',
                    boundaryGap: ['0%', '0%'],
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    axisLabel: {
                        color: '#D7F1FF',
                        align: 'center',
                        fontSize: 16,
                        padding: [0, 0, 0, 10],
                    },
                    boundaryGap: false,
                    data: [
                        '1月',
                        '2月',
                        '3月',
                        '4月',
                        '5月',
                        '6月',
                        '7月',
                        '8月',
                        '9月',
                        '10月',
                        '11月',
                        '12月',
                    ],
                    splitLine: {
                        show: false,
                    },
                },
                yAxis: {
                    // min: 0, //取0为最小刻度
                    max: 110,
                    type: 'value',
                    axisLabel: {
                        color: '#D7F1FF',
                        interval: 0,
                        showMinLabel: false,
                        showMaxLabel: false,
                        fontSize: 16,
                        formatter: function (value) {
                            return value + '%'
                        },
                    },
                    axisLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                    splitLine: {
                        lineStyle: {
                            color: 'rgba(154,199,220, 0.2)',
                        },
                    },
                },
                series: this.seriesData,
            }
            this.trendChartOption &&
                this.trendChart.setOption(this.trendChartOption)
            window.addEventListener('resize', () => this.trendChart.resize())
        },
        loadData() {
            this.loading = true
            let data = JSON.parse(sessionStorage.getItem('searchDate'))
            data.projectId = this.projectId
            apiList.getProjectLineChartData(data, (res) => {
                this.valueData = res.data
                this.legendData = Object.keys(res.data)
                this.legendData.forEach((legend, index) => {
                    this.seriesData[index] = {
                        name: legend,
                        type: 'line',
                        data: res.data[legend].map((item) => {
                            let actualRate = item.actualIndexCompleteRate
                            let value
                            if (actualRate > 100) {
                                value = 105
                            }
                            // else if (actualRate < 0) {
                            //     value = 0
                            // }
                            else {
                                value = actualRate
                            }
                            let objData = {
                                value,
                                actualRate,
                            }
                            return objData
                        }),
                        emphasis: {
                            focus: 'series',
                            endLabel: {
                                show: true,
                                formatter: (arg) => {
                                    let seriesName = arg.seriesName
                                    let lines = Math.ceil(seriesName.length / 8)
                                    let str = '',
                                        start = 0,
                                        end = 8
                                    for (let i = 1; i <= lines; i++) {
                                        if (i > 1) {
                                            start = end
                                            end = i * 8
                                        } else if (i == lines) {
                                            end = str.length
                                        }
                                        str += `{a|${seriesName.slice(
                                            start,
                                            end
                                        )}}\n`
                                    }

                                    return str
                                },
                                rich: {
                                    a: {
                                        backgroundColor: 'rgba(6, 47, 107, 1)',
                                    },
                                },
                                color: '#D7F1FF',
                                fontSize: 14,
                                lineHeight: 20,
                            },
                        },
                    }
                })
                console.log(this.seriesData, 'this.seriesData')
                this.initTrendChart()
                this.loading = false
            })
        },
        open(data) {
            let {projectName, projectId} = data
            this.projectId = projectId
            this.title = projectName
            this.dialogVisible = true
            this.$nextTick(() => {
                this.initTrendChart()
                this.loadData()
            })
        },
        handleClose() {
            this.trendChart.clear
            this.dialogVisible = false
        },
    },
}
</script>

<style lang="scss" scoped>
/deep/.el-input--suffix {
    text-align: center;
    border: none;

    .el-input__inner {
        border: none;
        background: transparent;
        color: #fff;
        padding: 0;
        text-align: center;
    }

    .el-select__caret {
        display: none;
    }
}

::v-deep .v-modal {
    display: none !important;
}

::v-deep .easy-dialog {
    //background: url("~@/assets/images/easy-dialog/dialog-bg.png") no-repeat;
    background-size: 100% 100%;
    box-sizing: border-box;
    border: 1px solid #0273E9;
    background-color: #01215a;
    padding-bottom: 26px;
    // height: 90vh;
    width: 80%;

    .title-diy {
        width: 100%;
        height: 50px;
        display: flex;
        justify-content: center;
        align-items: center;
        // padding-left: 24px;
        box-sizing: border-box;

        .title {
            font-size: 18px;
            font-family: Source Han Sans CN;
            font-weight: 800;
            color: #FFFFFF;
            position: relative;
            text-shadow: 0px 0px 0.83333vw #266bf2;
        }

        .title::after,
        .title::before {
            content: '';
            position: absolute;
            top: 50%;
            width: 40px;
            height: 4px;
            transform: translateY(-50%);
        }

        .title::before {
            right: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line63.png') no-repeat center / 100% 100%;
        }

        .title::after {
            left: calc(100% + 20px);
            background: url('~@/assets/img/bigScreen/line62.png') no-repeat center / 100% 100%;
        }
    }

    .el-dialog__body {
        max-height: 90vh !important
    }




    .content-diy {
        box-sizing: border-box;
        // max-height: calc(900px - 44px - 30px);
        overflow-y: auto;
        padding: 20px 24px;
        box-sizing: border-box;
        height: 68vh;


        /* 设置滚动条的样式 */
        &::-webkit-scrollbar {
            width: 8px !important; //垂直方向上的宽
            height: 8px !important; //水平方向上的宽
        }

        /* 滚动槽 */
        &::-webkit-scrollbar-track {
            border-radius: 0;
            background-color: #01215a !important;
        }

        /* 滚动条滑块 */
        &::-webkit-scrollbar-thumb {
            border-radius: 18px;
            background-color: rgba(#fff, 0.1) !important;
        }

        /*滚动条交叉样式*/
        &::-webkit-scrollbar-corner {
            background: #01215a !important;
        }
    }

    .footer-diy {
        display: flex;
        justify-content: center;
    }

    .el-dialog__header {
        width: 0;
        height: 0;
        padding: 0;
    }

    .el-dialog__body {
        padding: 0;
    }

    .cloes-icon {
        width: 20px;
        height: 20px;
        position: absolute;
        top: 6px;
        right: 6px;
        cursor: pointer;
    }

    .decoration {
        width: 100%;
        height: 100%;
        position: absolute;
        left: 0;
        top: 0;
    }


    #trend-chart {
        width: 80%;
        height: 100%;
        margin: 0 10%;
    }
}
</style>
